@@ -14,12 +14,17 @@
 #    under the License.
 
 import abc
-import collections
 
 import six
 
-HealthcheckResult = collections.namedtuple(
-    'HealthcheckResult', ['available', 'reason'])
+
+class HealthcheckResult(object):
+    """Result of a ``healthcheck`` method call should be this object."""
+
+    def __init__(self, available, reason, details=None):
+        self.available = available
+        self.reason = reason
+        self.details = details
 
 
 @six.add_metaclass(abc.ABCMeta)
